@@ -3,6 +3,7 @@ Provides functions to perform operations on ℝ³ Vectors centered at the
 Origin (0, 0, 0)"""
 
 from math import acos, cos, degrees, exp, hypot, isclose, radians, sin
+from types import GeneratorType
 import matplotlib.pyplot as plt
 from random import uniform
 
@@ -302,8 +303,6 @@ class Vector():
             • {'x': x, 'y': y, 'z': z}
             • {'i': x, 'j': y, 'k': z}"""
 
-        from types import GeneratorType
-
         if not isinstance(sequence, (dict, list, tuple, GeneratorType)):
             raise TypeError(" ".join((
                 "invalid sequence type for 'Vector':",
@@ -361,7 +360,10 @@ class Vector():
             Vector.ExceptionVector(*vectors)
 
         ax = plt.axes(projection="3d")
-        colors = ["red", "orange", "green", "blue", "purple"] * len(vectors)
+        colors = [
+            "red", "orange", "green", "blue", "purple",
+            "cyan", "magenta", "yellow", "brown", "gray",
+        ] * len(vectors)
 
         X = abs(max(vectors, key=lambda vec: abs(vec.x)))
         Y = abs(max(vectors, key=lambda vec: abs(vec.y)))
